@@ -1,7 +1,7 @@
 #include "transferitem.h"
 #include "utils.h"
 #include "captchadialog.h"
-#include "qplatformdefs.h"
+#include <qplatformdefs.h>
 #include "session.h"
 #ifdef MEEGO_EDITION_HARMATTAN
 #include "../harmattan/qmlutils.h"
